@@ -11,16 +11,29 @@
 
 #pragma once
 
+#include "kcmutils_version.h"
 #include "kmail_export.h"
-
+#include <QObject>
+#if KCMUTILS_VERSION >= QT_VERSION_CHECK(5, 240, 0)
 #include <KCModule>
+#include <KPluginMetaData>
+#else
+#include <KCModule>
+#endif
 class ConfigModule : public KCModule
 {
 public:
-    explicit ConfigModule(QWidget *parent = nullptr, const QVariantList &args = {})
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
+    explicit ConfigModule(QWidget *parent, const QVariantList &args)
         : KCModule(parent, args)
     {
     }
+#else
+    explicit ConfigModule(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+        : KCModule(parent, data, args)
+    {
+    }
+#endif
 
     ~ConfigModule() override = default;
 
