@@ -4,8 +4,8 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "../../../sieveimapinterface/kmailsieveimapinstanceinterface.h"
-#include "../../../sieveimapinterface/kmsieveimappasswordprovider.h"
+#include "sieveimapinterface/kmailsieveimapinstanceinterface.h"
+#include "sieveimapinterface/kmsieveimappasswordprovider.h"
 #include <KSieveUi/SieveDebugDialog>
 #include <KSieveUi/SieveImapInstanceInterfaceManager>
 
@@ -22,8 +22,7 @@ int main(int argc, char **argv)
 
     KSieveUi::SieveImapInstanceInterfaceManager::self()->setSieveImapInstanceInterface(new KMailSieveImapInstanceInterface);
     KMSieveImapPasswordProvider provider(nullptr);
-    auto dlg = new KSieveUi::SieveDebugDialog(&provider);
-    dlg->exec();
-    delete dlg;
+    auto dlg = KSieveUi::SieveDebugDialog(&provider);
+    dlg.exec();
     return 0;
 }
